contrib/import-checker.py
changeset 20197 761f2929a6ad
parent 20038 c65a6937b828
child 20198 f5393a9dc4e5
--- a/contrib/import-checker.py	Tue Dec 24 17:44:23 2013 -0500
+++ b/contrib/import-checker.py	Sun Dec 22 14:10:26 2013 -0800
@@ -48,11 +48,14 @@
     for m in 'ctypes', 'email':
         yield m
     yield 'builtins' # python3 only
+    stdlib_prefixes = set([sys.prefix, sys.exec_prefix])
     for libpath in sys.path:
-        # We want to walk everything in sys.path that starts with
-        # either sys.prefix or sys.exec_prefix.
-        if not (libpath.startswith(sys.prefix)
-                or libpath.startswith(sys.exec_prefix)):
+        # We want to walk everything in sys.path that starts with something
+        # in stdlib_prefixes.
+        for prefix in stdlib_prefixes:
+            if libpath.startswith(prefix):
+                break
+        else:
             continue
         if 'site-packages' in libpath:
             continue